//  Copyright 2016 root.ext@gmail.com
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

/// Dart Native Access
library dna;

import 'dart-ext:dna';
import 'dart:typed_data';
import 'dart:mirrors';

part 'dynamic_library.dart';
part 'utils.dart';
part 'coder.dart';
part 'model/pointer.dart';
part 'model/library.dart';
part 'model/param.dart';
part 'model/out.dart';
part 'model/ref.dart';
part 'model/method.dart';
part 'model/struct.dart';
part 'model/field.dart';

/// Type constants
const int C_CHAR = 99;
const int C_UCHAR = 67;
const int C_SHORT = 115;
const int C_USHORT = 83;
const int C_INT = 105;
const int C_UINT = 73;
const int C_LONG = 106;
const int C_ULONG = 74;
const int C_LONGLONG = 108;
const int C_ULONGLONG = 76;
const int C_FLOAT = 102;
const int C_DOUBLE = 100;
const int C_BOOL = 66;

const int C_POINTER = 112;
const int C_STRUCT = 84;
const int C_STRING = 90;

const int C_INT8 = 49;
const int C_INT16 = 50;
const int C_INT32 = 52;
const int C_INT64 = 56;

const int VOID = 86;
const int TYPEDDATA = 68;
const int LISTINT = 88;
const int LISTSTRING = 89;

int createCallVM(int size) native "createCallVM";
void freeCallVM(int vm) native "freeCallVM";

int loadLibrary(String name) native "loadLibrary";
void freeLibrary(int lib) native "freeLibrary";
int findSymbol(int lib, String name) native "findSymbol";

void pushParameters(int vm, String signature, List<Object> args) native "pushParameters";
dynamic callFunction(int vm, int pointer, String signature) native "callFunction";

List<int> getSizes() native "getSizes";
int getPointer(TypedData data) native "getPointer";
